@@ -22,21 +22,28 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 import json
+from unittest.mock import MagicMock
 
-from ansible_collections.ansible.netcommon.tests.unit.compat.mock import (
-    MagicMock,
-)
+import pytest
 from ansible.errors import AnsibleConnectionFailure
 from ansible.module_utils._text import to_text
 from ansible.playbook.play_context import PlayContext
 from ansible.plugins.loader import connection_loader
-import pytest
+from ansible_collections.ansible.netcommon.plugins.connection.network_cli import (
+    terminal_loader,
+)
 
 
 @pytest.fixture(name="conn")
-def plugin_fixture():
+def plugin_fixture(monkeypatch):
+
     pc = PlayContext()
-    pc.network_os = "ios"
+    pc.network_os = "fakeos"
+
+    def get(*args, **kwargs):
+        return MagicMock()
+
+    monkeypatch.setattr(terminal_loader, "get", get)
     conn = connection_loader.get(
         "ansible.netcommon.network_cli", pc, "/dev/null"
     )
@@ -55,7 +62,7 @@ def test_network_cli_invalid_os(network_os):
 @pytest.mark.parametrize("look_for_keys", [True, False, None])
 @pytest.mark.parametrize("password", ["password", None])
 @pytest.mark.parametrize("private_key_file", ["/path/to/key/file", None])
-@pytest.mark.parametrize("ssh_type", ["paramiko", "libssh"])
+@pytest.mark.parametrize("ssh_type", ["paramiko", "libssh", "auto"])
 def test_look_for_keys(
     conn, look_for_keys, password, private_key_file, ssh_type
 ):
@@ -81,7 +88,7 @@ def test_look_for_keys(
         assert conn.ssh_type_conn.get_option("look_for_keys") is True
 
 
-@pytest.mark.parametrize("ssh_type", ["paramiko", "libssh"])
+@pytest.mark.parametrize("ssh_type", ["paramiko", "libssh", "auto"])
 def test_options_pass_through(conn, ssh_type):
     conn.set_options(
         direct={
@@ -104,6 +111,26 @@ def test_options_pass_through(conn, ssh_type):
     assert conn.ssh_type_conn.get_option("proxy_command") == "do a proxy"
 
 
+@pytest.mark.parametrize("has_libssh", (True, False))
+def test_network_cli_ssh_type_auto(conn, has_libssh):
+    """Test that ssh_type: auto resolves to the correct option."""
+    from ansible_collections.ansible.netcommon.plugins.connection import (
+        network_cli,
+    )
+
+    network_cli.HAS_PYLIBSSH = has_libssh
+
+    conn.set_options(
+        direct={
+            "ssh_type": "auto",
+        }
+    )
+    if has_libssh:
+        assert conn.ssh_type == "libssh"
+    else:
+        assert conn.ssh_type == "paramiko"
+
+
 @pytest.mark.parametrize(
     "become_method,become_pass", [("enable", "password"), (None, None)]
 )
@@ -152,9 +179,11 @@ def test_network_cli_exec_command(conn, command):
         ),
     ],
 )
-def test_network_cli_send(conn, response):
+@pytest.mark.parametrize("ssh_type", ["paramiko", "libssh", "auto"])
+def test_network_cli_send(conn, response, ssh_type):
     conn.set_options(
         direct={
+            "ssh_type": ssh_type,
             "terminal_stderr_re": [{"pattern": "^ERROR"}],
             "terminal_stdout_re": [{"pattern": "device#"}],
         }
@@ -165,7 +194,10 @@ def test_network_cli_send(conn, response):
     conn._ssh_shell = mock__shell
     conn._connected = True
 
-    mock__shell.recv.side_effect = [response, None]
+    if conn.ssh_type == "paramiko":
+        mock__shell.recv.side_effect = [response, None]
+    elif conn.ssh_type == "libssh":
+        mock__shell.read_bulk_response.side_effect = [response, None]
     conn.send(b"command")
 
     mock__shell.sendall.assert_called_with(b"command\r")
