@@ -7,32 +7,36 @@
 DOCUMENTATION = r"""
 ---
 module: anc_endpoint_clear
-short_description: Resource module for Anc Endpoint Clear
+short_description: Resource module for ANC Endpoint Clear
 description:
-- Manage operation update of the resource Anc Endpoint Clear.
+- Manage operation update of the resource ANC Endpoint Clear.
+- This API allows the client to clear the required configuration.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
 options:
   additionalData:
-    description: Anc Endpoint Clear's additionalData.
+    description: ANC Endpoint Clear's additionalData.
+    elements: dict
     suboptions:
       name:
-        description: Anc Endpoint Clear's name.
+        description: ANC Endpoint Clear's name.
         type: str
       value:
-        description: Anc Endpoint Clear's value.
+        description: ANC Endpoint Clear's value.
         type: str
     type: list
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.1
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Anc Endpoint Clear reference
-  description: Complete reference of the Anc Endpoint Clear object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    anc_endpoint.AncEndpoint.clear_anc_endpoint,
+
+  - Paths used are
+    put /ers/config/ancendpoint/clear,
+
 """
 
 EXAMPLES = r"""
