@@ -10,19 +10,29 @@ module: device_administration_authorization_reset_hitcount
 short_description: Resource module for Device Administration Authorization Reset Hitcount
 description:
 - Manage operation create of the resource Device Administration Authorization Reset Hitcount.
+- Device Admin - Reset HitCount for Authorization Rules.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
-options: {}
+options:
+  policyId:
+    description: PolicyId path parameter. Policy id.
+    type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.1
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Device Administration Authorization Reset Hitcount reference
-  description: Complete reference of the Device Administration Authorization Reset Hitcount object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Device Administration - Authorization Rules
+  description: Complete reference of the Device Administration - Authorization Rules API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+notes:
+  - SDK Method used are
+    device_administration_authorization_rules.DeviceAdministrationAuthorizationRules.reset_hit_counts_device_admin_authorization_rules,
+
+  - Paths used are
+    post /device-admin/policy-set/{policyId}/authorization/reset-hitcount,
+
 """
 
 EXAMPLES = r"""
@@ -32,6 +42,7 @@ EXAMPLES = r"""
     ise_username: "{{ise_username}}"
     ise_password: "{{ise_password}}"
     ise_verify: "{{ise_verify}}"
+    policyId: string
 
 """
 
