@@ -10,19 +10,26 @@ module: device_administration_command_set_info
 short_description: Information module for Device Administration Command Set
 description:
 - Get all Device Administration Command Set.
+- Device Admin - Return list of command sets.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.1
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Device Administration Command Set reference
-  description: Complete reference of the Device Administration Command Set object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Device Administration - Command Set
+  description: Complete reference of the Device Administration - Command Set API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+notes:
+  - SDK Method used are
+    device_administration_command_set.DeviceAdministrationCommandSet.get_device_admin_command_sets,
+
+  - Paths used are
+    get /device-admin/command-sets,
+
 """
 
 EXAMPLES = r"""
