@@ -7,9 +7,11 @@
 DOCUMENTATION = r"""
 ---
 module: guest_smtp_notification_settings
-short_description: Resource module for Guest Smtp Notification Settings
+short_description: Resource module for Guest SMTP Notification Settings
 description:
-- Manage operations create and update of the resource Guest Smtp Notification Settings.
+- Manage operations create and update of the resource Guest SMTP Notification Settings.
+- This API creates a guest SMTP notification configuration.
+- This API allows the client to update a SMTP configuration setting.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
@@ -22,7 +24,7 @@ options:
     description: The default from email address to be used to send emails from.
     type: str
   id:
-    description: Guest Smtp Notification Settings's id.
+    description: Guest SMTP Notification Settings's id.
     type: str
   notificationEnabled:
     description: Indicates if the email notification service is to be enabled.
@@ -52,13 +54,17 @@ options:
     description: Username of Secure SMTP server.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.1
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Guest Smtp Notification Settings reference
-  description: Complete reference of the Guest Smtp Notification Settings object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    guest_smtp_notification_configuration.GuestSmtpNotificationConfiguration.create_guest_smtp_notification_settings,
+    guest_smtp_notification_configuration.GuestSmtpNotificationConfiguration.update_guest_smtp_notification_settings_by_id,
+
+  - Paths used are
+    post /ers/config/guestsmtpnotificationsettings,
+    put /ers/config/guestsmtpnotificationsettings/{id},
+
 """
 
 EXAMPLES = r"""
@@ -129,16 +135,18 @@ ise_response:
 ise_update_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
-  version_added: "1.1.0"
+  version_added: '1.1.0'
   type: dict
   sample: >
     {
       "UpdatedFieldsList": {
-        "updatedField": {
-          "field": "string",
-          "oldValue": "string",
-          "newValue": "string"
-        },
+        "updatedField": [
+          {
+            "field": "string",
+            "oldValue": "string",
+            "newValue": "string"
+          }
+        ],
         "field": "string",
         "oldValue": "string",
         "newValue": "string"
