@@ -10,19 +10,29 @@ module: network_access_authentication_rules_reset_hitcount
 short_description: Resource module for Network Access Authentication Rules Reset Hitcount
 description:
 - Manage operation create of the resource Network Access Authentication Rules Reset Hitcount.
+- Network Access - Reset HitCount for Authentication Rules.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
-options: {}
+options:
+  policyId:
+    description: PolicyId path parameter. Policy id.
+    type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.1
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Network Access Authentication Rules Reset Hitcount reference
-  description: Complete reference of the Network Access Authentication Rules Reset Hitcount object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Network Access - Authentication Rules
+  description: Complete reference of the Network Access - Authentication Rules API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+notes:
+  - SDK Method used are
+    network_access_authentication_rules.NetworkAccessAuthenticationRules.reset_hit_counts_network_access_authentication_rules,
+
+  - Paths used are
+    post /network-access/policy-set/{policyId}/authentication/reset-hitcount,
+
 """
 
 EXAMPLES = r"""
@@ -32,6 +42,7 @@ EXAMPLES = r"""
     ise_username: "{{ise_username}}"
     ise_password: "{{ise_password}}"
     ise_verify: "{{ise_verify}}"
+    policyId: string
 
 """
 
