@@ -7,25 +7,27 @@
 DOCUMENTATION = r"""
 ---
 module: pxgrid_access_secret
-short_description: Resource module for Pxgrid Access Secret
+short_description: Resource module for pxGrid Access Secret
 description:
-- Manage operation create of the resource Pxgrid Access Secret.
+- Manage operation create of the resource pxGrid Access Secret.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
 options:
   peerNodeName:
-    description: Pxgrid Access Secret's peerNodeName.
+    description: pxGrid Access Secret's peerNodeName.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.1
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Pxgrid Access Secret reference
-  description: Complete reference of the Pxgrid Access Secret object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    consumer.Consumer.access_secret,
+
+  - Paths used are
+    post /control/AccessSecret,
+
 """
 
 EXAMPLES = r"""
