@@ -7,26 +7,28 @@
 DOCUMENTATION = r"""
 ---
 module: pxgrid_user_groups_info
-short_description: Information module for Pxgrid User Groups Info
+short_description: Information module for pxGrid User Groups Info
 description:
-- Get Pxgrid User Groups Info.
+- Get pxGrid User Groups Info.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.1
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Pxgrid User Groups Info reference
-  description: Complete reference of the Pxgrid User Groups Info object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    session_directory.SessionDirectory.get_user_groups,
+
+  - Paths used are
+    post /ise/session/getUserGroups,
+
 """
 
 EXAMPLES = r"""
-- name: Get all Pxgrid User Groups Info
+- name: Get all pxGrid User Groups Info
   cisco.ise.pxgrid_user_groups_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
@@ -41,6 +43,6 @@ ise_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
   type: dict
-  sample:
-  - {}
+  sample: >
+    {}
 """
