@@ -7,10 +7,12 @@
 DOCUMENTATION = r"""
 ---
 module: radius_server_sequence_info
-short_description: Information module for Radius Server Sequence
+short_description: Information module for RADIUS Server Sequence
 description:
-- Get all Radius Server Sequence.
-- Get Radius Server Sequence by id.
+- Get all RADIUS Server Sequence.
+- Get RADIUS Server Sequence by id.
+- This API allows the client to get a RADIUS server sequence by ID.
+- This API allows the client to get all the RADIUS server sequences.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
@@ -29,17 +31,21 @@ options:
     - Size query parameter. Number of objects returned per page.
     type: int
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.1
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Radius Server Sequence reference
-  description: Complete reference of the Radius Server Sequence object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    radius_server_sequence.RadiusServerSequence.get_radius_server_sequence_by_id,
+    radius_server_sequence.RadiusServerSequence.get_radius_server_sequence_generator,
+
+  - Paths used are
+    get /ers/config/radiusserversequence,
+    get /ers/config/radiusserversequence/{id},
+
 """
 
 EXAMPLES = r"""
-- name: Get all Radius Server Sequence
+- name: Get all RADIUS Server Sequence
   cisco.ise.radius_server_sequence_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
@@ -49,7 +55,7 @@ EXAMPLES = r"""
     size: 20
   register: result
 
-- name: Get Radius Server Sequence by id
+- name: Get RADIUS Server Sequence by id
   cisco.ise.radius_server_sequence_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
@@ -106,10 +112,11 @@ ise_response:
         "type": "string"
       }
     }
+
 ise_responses:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
-  version_added: "1.1.0"
+  version_added: '1.1.0'
   type: list
   elements: dict
   sample: >
@@ -118,6 +125,36 @@ ise_responses:
         "id": "string",
         "name": "string",
         "description": "string",
+        "stripPrefix": true,
+        "stripSuffix": true,
+        "prefixSeparator": "string",
+        "suffixSeparator": "string",
+        "remoteAccounting": true,
+        "localAccounting": true,
+        "useAttrSetOnRequest": true,
+        "useAttrSetBeforeAcc": true,
+        "continueAuthorzPolicy": true,
+        "RadiusServerList": [
+          "string"
+        ],
+        "OnRequestAttrManipulatorList": [
+          {
+            "action": "string",
+            "dictionaryName": "string",
+            "attributeName": "string",
+            "value": "string",
+            "changedVal": "string"
+          }
+        ],
+        "BeforeAcceptAttrManipulatorsList": [
+          {
+            "action": "string",
+            "dictionaryName": "string",
+            "attributeName": "string",
+            "value": "string",
+            "changedVal": "string"
+          }
+        ],
         "link": {
           "rel": "string",
           "href": "string",
