@@ -7,25 +7,28 @@
 DOCUMENTATION = r"""
 ---
 module: sg_acl
-short_description: Resource module for Sg Acl
+short_description: Resource module for SGACL
 description:
-- Manage operations create, update and delete of the resource Sg Acl.
+- Manage operations create, update and delete of the resource SGACL.
+- This API creates a security group ACL.
+- This API deletes a security group ACL.
+- This API allows the client to update a security group ACL.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
 options:
   aclcontent:
-    description: Sg Acl's aclcontent.
+    description: SGACL's aclcontent.
     type: str
   description:
-    description: Sg Acl's description.
+    description: SGACL's description.
     type: str
   generationId:
-    description: Sg Acl's generationId.
+    description: SGACL's generationId.
     type: str
   id:
-    description: Sg Acl's id.
+    description: SGACL's id.
     type: str
   ipVersion:
     description: Allowed values - IPV4, - IPV6, - IP_AGNOSTIC.
@@ -37,16 +40,26 @@ options:
     description: Modelled content of contract.
     type: dict
   name:
-    description: Sg Acl's name.
+    description: SGACL's name.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.1
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Sg Acl reference
-  description: Complete reference of the Sg Acl object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for SecurityGroupsACLs
+  description: Complete reference of the SecurityGroupsACLs API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!sgacl
+notes:
+  - SDK Method used are
+    security_groups_acls.SecurityGroupsAcls.create_security_groups_acl,
+    security_groups_acls.SecurityGroupsAcls.delete_security_groups_acl_by_id,
+    security_groups_acls.SecurityGroupsAcls.update_security_groups_acl_by_id,
+
+  - Paths used are
+    post /ers/config/sgacl,
+    delete /ers/config/sgacl/{id},
+    put /ers/config/sgacl/{id},
+
 """
 
 EXAMPLES = r"""
@@ -117,16 +130,18 @@ ise_response:
 ise_update_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
-  version_added: "1.1.0"
+  version_added: '1.1.0'
   type: dict
   sample: >
     {
       "UpdatedFieldsList": {
-        "updatedField": {
-          "field": "string",
-          "oldValue": "string",
-          "newValue": "string"
-        },
+        "updatedField": [
+          {
+            "field": "string",
+            "oldValue": "string",
+            "newValue": "string"
+          }
+        ],
         "field": "string",
         "oldValue": "string",
         "newValue": "string"
