@@ -7,10 +7,12 @@
 DOCUMENTATION = r"""
 ---
 module: sg_mapping_group_info
-short_description: Information module for Sg Mapping Group
+short_description: Information module for SG Mapping Group
 description:
-- Get all Sg Mapping Group.
-- Get Sg Mapping Group by id.
+- Get all SG Mapping Group.
+- Get SG Mapping Group by id.
+- This API allows the client to get all the IP to SGT mapping groups.
+- This API allows the client to get an IP to SGT mapping group by ID.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
@@ -39,14 +41,22 @@ options:
   filter:
     description:
     - >
-      Filter query parameter. <br/> **Simple filtering** should be available through the filter query string
-      parameter. The structure of a filter is a triplet of field operator and value separated with dots. More than
-      one filter can be sent. The logical operator common to ALL filter criteria will be by default AND, and can
-      be changed by using the "filterType=or" query string parameter. Each resource Data model description should
-      specify if an attribute is a filtered field. <br/> Operator | Description <br/>
-      ------------|----------------- <br/> EQ | Equals <br/> NEQ | Not Equals <br/> GT | Greater Than <br/> LT |
-      Less Then <br/> STARTSW | Starts With <br/> NSTARTSW | Not Starts With <br/> ENDSW | Ends With <br/> NENDSW
-      | Not Ends With <br/> CONTAINS | Contains <br/> NCONTAINS | Not Contains <br/>.
+      Filter query parameter. **Simple filtering** should be available through the filter query string parameter.
+      The structure of a filter is a triplet of field operator and value separated with dots. More than one filter
+      can be sent. The logical operator common to ALL filter criteria will be by default AND, and can be changed
+      by using the "filterType=or" query string parameter.
+    - Each resource Data model description should specify if an attribute is a filtered field.
+    - The 'EQ' operator describes 'Equals'.
+    - The 'NEQ' operator describes 'Not Equals'.
+    - The 'GT' operator describes 'Greater Than'.
+    - The 'LT' operator describes 'Less Than'.
+    - The 'STARTSW' operator describes 'Starts With'.
+    - The 'NSTARTSW' operator describes 'Not Starts With'.
+    - The 'ENDSW' operator describes 'Ends With'.
+    - The 'NENDSW' operator describes 'Not Ends With'.
+    - The 'CONTAINS' operator describes 'Contains'.
+    - The 'NCONTAINS' operator describes 'Not Contains'.
+    elements: str
     type: list
   filterType:
     description:
@@ -55,17 +65,25 @@ options:
       can be changed by using the parameter.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.1
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Sg Mapping Group reference
-  description: Complete reference of the Sg Mapping Group object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for IPToSGTMappingGroup
+  description: Complete reference of the IPToSGTMappingGroup API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!sgmappinggroup
+notes:
+  - SDK Method used are
+    ip_to_sgt_mapping_group.IpToSgtMappingGroup.get_ip_to_sgt_mapping_group_by_id,
+    ip_to_sgt_mapping_group.IpToSgtMappingGroup.get_ip_to_sgt_mapping_group_generator,
+
+  - Paths used are
+    get /ers/config/sgmappinggroup,
+    get /ers/config/sgmappinggroup/{id},
+
 """
 
 EXAMPLES = r"""
-- name: Get all Sg Mapping Group
+- name: Get all SG Mapping Group
   cisco.ise.sg_mapping_group_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
@@ -79,7 +97,7 @@ EXAMPLES = r"""
     filterType: AND
   register: result
 
-- name: Get Sg Mapping Group by id
+- name: Get SG Mapping Group by id
   cisco.ise.sg_mapping_group_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
@@ -107,17 +125,20 @@ ise_response:
         "type": "string"
       }
     }
+
 ise_responses:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
-  version_added: "1.1.0"
+  version_added: '1.1.0'
   type: list
   elements: dict
   sample: >
     [
       {
-        "id": "string",
         "name": "string",
+        "sgt": "string",
+        "deployTo": "string",
+        "deployType": "string",
         "link": {
           "rel": "string",
           "href": "string",
