@@ -7,32 +7,35 @@
 DOCUMENTATION = r"""
 ---
 module: sgt
-short_description: Resource module for Sgt
+short_description: Resource module for SGt
 description:
-- Manage operations create, update and delete of the resource Sgt.
+- Manage operations create, update and delete of the resource SGt.
+- This API creates a security group.
+- This API deletes a security group.
+- This API allows the client to update a security group.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
 options:
   defaultSGACLs:
-    description: Sgt's defaultSGACLs.
+    description: SGt's defaultSGACLs.
     elements: dict
     type: list
   description:
-    description: Sgt's description.
+    description: SGt's description.
     type: str
   generationId:
-    description: Sgt's generationId.
-    type: int
+    description: SGt's generationId.
+    type: str
   id:
-    description: Sgt's id.
+    description: SGt's id.
     type: str
   isReadOnly:
     description: IsReadOnly flag.
     type: bool
   name:
-    description: Sgt's name.
+    description: SGt's name.
     type: str
   propogateToApic:
     description: PropogateToApic flag.
@@ -41,13 +44,23 @@ options:
     description: Value range 2 ot 65519 or -1 to auto-generate.
     type: int
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.1
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Sgt reference
-  description: Complete reference of the Sgt object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for SecurityGroups
+  description: Complete reference of the SecurityGroups API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!sgt
+notes:
+  - SDK Method used are
+    security_groups.SecurityGroups.create_security_group,
+    security_groups.SecurityGroups.delete_security_group_by_id,
+    security_groups.SecurityGroups.update_security_group_by_id,
+
+  - Paths used are
+    post /ers/config/sgt,
+    delete /ers/config/sgt/{id},
+    put /ers/config/sgt/{id},
+
 """
 
 EXAMPLES = r"""
@@ -61,7 +74,7 @@ EXAMPLES = r"""
     defaultSGACLs:
     - {}
     description: string
-    generationId: 0
+    generationId: string
     id: string
     isReadOnly: true
     name: string
@@ -87,7 +100,7 @@ EXAMPLES = r"""
     defaultSGACLs:
     - {}
     description: string
-    generationId: 0
+    generationId: string
     isReadOnly: true
     name: string
     propogateToApic: true
@@ -106,7 +119,7 @@ ise_response:
       "name": "string",
       "description": "string",
       "value": 0,
-      "generationId": 0,
+      "generationId": "string",
       "isReadOnly": true,
       "propogateToApic": true,
       "defaultSGACLs": [
@@ -122,16 +135,18 @@ ise_response:
 ise_update_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
-  version_added: "1.1.0"
+  version_added: '1.1.0'
   type: dict
   sample: >
     {
       "UpdatedFieldsList": {
-        "updatedField": {
-          "field": "string",
-          "oldValue": "string",
-          "newValue": "string"
-        },
+        "updatedField": [
+          {
+            "field": "string",
+            "oldValue": "string",
+            "newValue": "string"
+          }
+        ],
         "field": "string",
         "oldValue": "string",
         "newValue": "string"
