@@ -10,6 +10,9 @@ module: sponsor_portal
 short_description: Resource module for Sponsor Portal
 description:
 - Manage operations create, update and delete of the resource Sponsor Portal.
+- This API creates a sponsor portal.
+- This API deletes a sponsor portal by ID.
+- This API allows the client to update a sponsor portal by ID.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
@@ -76,6 +79,7 @@ options:
         suboptions:
           data:
             description: The Dictionary will be exposed here as key value pair.
+            elements: dict
             suboptions:
               key:
                 description: Sponsor Portal's key.
@@ -179,6 +183,7 @@ options:
             type: bool
           socialConfigs:
             description: Sponsor Portal's socialConfigs.
+            elements: dict
             type: list
           timeBetweenLoginsDuringRateLimit:
             description: Time between login attempts when rate limiting.
@@ -191,14 +196,16 @@ options:
           allowedInterfaces:
             description: Interfaces that the portal will be reachable on. Allowed values
               - eth0, - eth1, - eth2, - eth3, - eth4, - eth5, - bond0, - bond1, - bond2.
-            type: str
+            elements: str
+            type: list
           authenticationMethod:
             description: Unique Id of the identity source sequence.
             type: str
-          availableSsids:
+          availableSSIDs:
             description: Names of the SSIDs available for assignment to guest users
               by sponsors.
-            type: str
+            elements: str
+            type: list
           certificateGroupTag:
             description: Logical name of the x.509 server certificate that will be used
               for the portal.
@@ -274,13 +281,19 @@ options:
         type: dict
     type: dict
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.1
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Sponsor Portal reference
-  description: Complete reference of the Sponsor Portal object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    sponsor_portal.SponsorPortal.create_sponsor_portal,
+    sponsor_portal.SponsorPortal.delete_sponsor_portal_by_id,
+    sponsor_portal.SponsorPortal.update_sponsor_portal_by_id,
+
+  - Paths used are
+    post /ers/config/sponsorportal,
+    delete /ers/config/sponsorportal/{id},
+    put /ers/config/sponsorportal/{id},
+
 """
 
 EXAMPLES = r"""
@@ -336,12 +349,15 @@ EXAMPLES = r"""
         maxFailedAttemptsBeforeRateLimit: 0
         requireAupAcceptance: true
         requireAupScrolling: true
-        socialConfigs: []
+        socialConfigs:
+        - {}
         timeBetweenLoginsDuringRateLimit: 0
       portalSettings:
-        allowedInterfaces: string
+        allowedInterfaces:
+        - string
         authenticationMethod: string
-        availableSsids: string
+        availableSsids:
+        - string
         certificateGroupTag: string
         displayLang: string
         fallbackLanguage: string
@@ -424,12 +440,15 @@ EXAMPLES = r"""
         maxFailedAttemptsBeforeRateLimit: 0
         requireAupAcceptance: true
         requireAupScrolling: true
-        socialConfigs: []
+        socialConfigs:
+        - {}
         timeBetweenLoginsDuringRateLimit: 0
       portalSettings:
-        allowedInterfaces: string
+        allowedInterfaces:
+        - string
         authenticationMethod: string
-        availableSsids: string
+        availableSsids:
+        - string
         certificateGroupTag: string
         displayLang: string
         fallbackLanguage: string
@@ -478,7 +497,9 @@ ise_response:
           "idleTimeout": 0,
           "displayLang": "string",
           "fallbackLanguage": "string",
-          "availableSsids": "string"
+          "availableSsids": [
+            "string"
+          ]
         },
         "loginPageSettings": {
           "maxFailedAttemptsBeforeRateLimit": 0,
@@ -487,7 +508,9 @@ ise_response:
           "aupDisplay": "string",
           "requireAupAcceptance": true,
           "requireAupScrolling": true,
-          "socialConfigs": []
+          "socialConfigs": [
+            {}
+          ]
         },
         "aupSettings": {
           "includeAup": true,
@@ -566,16 +589,18 @@ ise_response:
 ise_update_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
-  version_added: "1.1.0"
+  version_added: '1.1.0'
   type: dict
   sample: >
     {
       "UpdatedFieldsList": {
-        "updatedField": {
-          "field": "string",
-          "oldValue": "string",
-          "newValue": "string"
-        },
+        "updatedField": [
+          {
+            "field": "string",
+            "oldValue": "string",
+            "newValue": "string"
+          }
+        ],
         "field": "string",
         "oldValue": "string",
         "newValue": "string"
