@@ -10,6 +10,7 @@ module: trusted_certificate_export_info
 short_description: Information module for Trusted Certificate Export
 description:
 - Get Trusted Certificate Export by id.
+- The response of this API carries a trusted certificate file mapped to the.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
@@ -17,7 +18,7 @@ author: Rafael Campos (@racampos)
 options:
   id:
     description:
-    - Id path parameter. The ID of the Trusted Certificate to be exported.
+    - Id path parameter. ID of the Trusted Certificate to be exported.
     type: str
   dirPath:
     description:
@@ -27,14 +28,24 @@ options:
     description:
     - Enable or disable automatic file creation of raw response.
     type: bool
+  filename:
+    description:
+    - The filename used to save the download file.
+    type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.1
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Trusted Certificate Export reference
-  description: Complete reference of the Trusted Certificate Export object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Certificates
+  description: Complete reference of the Certificates API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!certificate-openapi
+notes:
+  - SDK Method used are
+    certificates.Certificates.export_trusted_certificate,
+
+  - Paths used are
+    get /api/v1/certs/trusted-certificate/export/{id},
+
 """
 
 EXAMPLES = r"""
@@ -53,7 +64,12 @@ RETURN = r"""
 ise_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
-  type: str
+  type: dict
   sample: >
-    "'string'"
+    {
+      "data": "filecontent",
+      "filename": "filename",
+      "dirpath": "download/directory",
+      "path": "download/directory/filename"
+    }
 """
