@@ -73,7 +73,7 @@ def _tmplt_users_auth(data):
 
 
 def _template_communities(data):
-    cmd = "snmp-server community {0}".format(data["community"])
+    cmd = "snmp-server community {0}".format(data["name"])
 
     if "group" in data:
         cmd += " group {0}".format(data["group"])
@@ -125,7 +125,7 @@ class Snmp_serverTemplate(NetworkTemplate):
             "result": {
                 "communities": [
                     {
-                        "community": "{{ community }}",
+                        "name": "{{ community }}",
                         "group": "{{ group }}",
                         "use_ipv4acl": "{{ use_ipv4acl }}",
                         "use_ipv6acl": "{{ use_ipv6acl }}",
@@ -138,7 +138,7 @@ class Snmp_serverTemplate(NetworkTemplate):
             "getval": re.compile(
                 r"""
                 ^snmp-server
-                \scontact\s(?P<contact>\S+)
+                \scontact\s(?P<contact>.+)
                 $""", re.VERBOSE),
             "setval": "snmp-server contact {{ contact }}",
             "result": {
@@ -158,7 +158,6 @@ class Snmp_serverTemplate(NetworkTemplate):
             "setval": "snmp-server context {{ context.name }}"
                       "{{ ' instance ' + context.instance if context.instance is defined else '' }}"
                       "{{ ' topology ' + context.topology if context.topology is defined else '' }}"
-                      "{{ ' instance ' + context.instance if context.instance is defined else '' }}"
                       "{{ ' vrf ' + context.vrf if context.vrf is defined else '' }}",
             "result": {
                 "context": {
@@ -249,6 +248,22 @@ class Snmp_serverTemplate(NetworkTemplate):
                 }
             },
         },
+        {
+            "name": "traps.bgp",
+            "getval": re.compile(
+                r"""
+                ^snmp-server\senable
+                \straps\s(?P<enable>bgp)
+                $""", re.VERBOSE),
+            "setval": "snmp-server enable traps bgp",
+            "result": {
+                "traps": {
+                    "bgp": {
+                        "enable": "{{ not not enable }}",
+                    }
+                }
+            },
+        },
         {
             "name": "traps.bridge.newroot",
             "getval": re.compile(
@@ -861,6 +876,38 @@ class Snmp_serverTemplate(NetworkTemplate):
                 }
             },
         },
+        {
+            "name": "traps.ospf",
+            "getval": re.compile(
+                r"""
+                ^snmp-server\senable
+                \straps\s(?P<enable>ospf)
+                $""", re.VERBOSE),
+            "setval": "snmp-server enable traps ospf",
+            "result": {
+                "traps": {
+                    "ospf": {
+                        "enable": "{{ not not enable }}",
+                    }
+                }
+            },
+        },
+        {
+            "name": "traps.ospfv3",
+            "getval": re.compile(
+                r"""
+                ^snmp-server\senable
+                \straps\s(?P<enable>ospfv3)
+                $""", re.VERBOSE),
+            "setval": "snmp-server enable traps ospfv3",
+            "result": {
+                "traps": {
+                    "ospfv3": {
+                        "enable": "{{ not not enable }}",
+                    }
+                }
+            },
+        },
         {
             "name": "traps.rf.redundancy_framework",
             "getval": re.compile(
@@ -1246,7 +1293,7 @@ class Snmp_serverTemplate(NetworkTemplate):
             "getval": re.compile(
                 r"""
                 ^snmp-server
-                \slocation\s(?P<location>\S+)
+                \slocation\s(?P<location>.+)
                 $""", re.VERBOSE),
             "setval": "snmp-server location {{ location }}",
             "result": {
