@@ -187,10 +187,10 @@ def update_tls_hostname(result, old_behavior=False, deprecate_function=None, use
             result['tls_hostname'] = DEFAULT_TLS_HOSTNAME
             if uses_tls and deprecate_function is not None:
                 deprecate_function(
-                    'The default value "localhost" for tls_hostname is deprecated and will be removed in community.docker 2.0.0.'
+                    'The default value "localhost" for tls_hostname is deprecated and will be removed in community.docker 3.0.0.'
                     ' From then on, docker_host will be used to compute tls_hostname. If you want to keep using "localhost",'
                     ' please set that value explicitly.',
-                    version='2.0.0', collection_name='community.docker')
+                    version='3.0.0', collection_name='community.docker')
             return
 
         # get default machine name from the url
@@ -525,11 +525,18 @@ class AnsibleDockerClientBase(Client):
                     self.log("Check for docker.io image: %s" % lookup)
                     images = self._image_lookup(lookup, tag)
                 if not images:
-                    # Last case: if docker.io wasn't there, it can be that
-                    # the image wasn't found either (#15586)
+                    # Last case for some Docker versions: if docker.io wasn't there,
+                    # it can be that the image wasn't found either
+                    # (https://github.com/ansible/ansible/pull/15586)
                     lookup = "%s/%s" % (registry, repo_name)
                     self.log("Check for docker.io image: %s" % lookup)
                     images = self._image_lookup(lookup, tag)
+                if not images and '/' not in repo_name:
+                    # This seems to be happening with podman-docker
+                    # (https://github.com/ansible-collections/community.docker/issues/291)
+                    lookup = "%s/library/%s" % (registry, repo_name)
+                    self.log("Check for docker.io image: %s" % lookup)
+                    images = self._image_lookup(lookup, tag)
 
         if len(images) > 1:
             self.fail("Registry returned more than one result for %s:%s" % (name, tag))
