@@ -51,7 +51,16 @@ options:
   append_privs:
     description:
       - Append the privileges defined by the I(priv) option to the existing ones
-        for this role instead of overwriting them.
+        for this role instead of overwriting them. Mutually exclusive with I(subtract_privs).
+    type: bool
+    default: no
+
+  subtract_privs:
+    description:
+      - Revoke the privileges defined by the I(priv) option and keep other existing privileges.
+        If set, invalid privileges in I(priv) are ignored.
+        Mutually exclusive with I(append_privs).
+    version_added: '3.2.0'
     type: bool
     default: no
 
@@ -119,7 +128,6 @@ seealso:
 
 author:
   - Andrew Klychkov (@Andersson007)
-  - Felix Hamme (@betanummeric)
 
 extends_documentation_fragment:
   - community.mysql.mysql
@@ -234,6 +242,14 @@ EXAMPLES = r'''
     name: business
     members:
     - marketing
+
+- name: Ensure the role foo does not have the DELETE privilege
+  community.mysql.mysql_role:
+    state: present
+    name: foo
+    subtract_privs: yes
+    priv:
+      'db1.*': DELETE
 '''
 
 RETURN = '''#'''
@@ -251,7 +267,6 @@ from ansible_collections.community.mysql.plugins.module_utils.user import (
     get_mode,
     user_mod,
     privileges_grant,
-    get_valid_privs,
     privileges_unpack,
 )
 from ansible.module_utils._text import to_native
@@ -823,9 +838,9 @@ class Role():
         return True
 
     def update(self, users, privs, check_mode=False,
-               append_privs=False, append_members=False,
-               detach_members=False, admin=False,
-               set_default_role_all=True):
+               append_privs=False, subtract_privs=False,
+               append_members=False, detach_members=False,
+               admin=False, set_default_role_all=True):
         """Update a role.
 
         Update a role if needed.
@@ -839,6 +854,8 @@ class Role():
             check_mode (bool): If True, just checks and does nothing.
             append_privs (bool): If True, adds new privileges passed through privs
                 not touching current privileges.
+            subtract_privs (bool): If True, revoke the privileges passed through privs
+                not touching other existing privileges.
             append_members (bool): If True, adds new members passed through users
                 not touching current members.
             detach_members (bool): If True, removes members passed through users from a role.
@@ -863,7 +880,7 @@ class Role():
         if privs:
             changed, msg = user_mod(self.cursor, self.name, self.host,
                                     None, None, None, None, None, None,
-                                    privs, append_privs, None,
+                                    privs, append_privs, subtract_privs, None,
                                     self.module, role=True, maria_role=self.is_mariadb)
 
         if admin:
@@ -879,11 +896,50 @@ class Role():
         Returns:
             set: Members.
         """
-        if self.is_mariadb:
-            self.cursor.execute('select user, host from mysql.roles_mapping where role = %s', (self.name,))
-        else:
-            self.cursor.execute('select TO_USER as user, TO_HOST as host from mysql.role_edges where FROM_USER = %s', (self.name,))
-        return set(self.cursor.fetchall())
+        members = set()
+
+        for user, host in self.server.get_users():
+            # Don't handle itself
+            if user == self.name and host == self.host:
+                continue
+
+            grants = self.server.get_grants(user, host)
+
+            if self.__is_member(grants):
+                members.add((user, host))
+
+        return members
+
+    def __is_member(self, grants):
+        """Check if a user / role is a member of a role.
+
+        To check if a user is a member of a role,
+        we parse their grants looking for the role name in them.
+        In the following grants, we can see that test@% is a member of readers.
+        +---------------------------------------------------+
+        | Grants for test@%                                 |
+        +---------------------------------------------------+
+        | GRANT SELECT, INSERT, UPDATE ON *.* TO `test`@`%` |
+        | GRANT ALL PRIVILEGES ON `mysql`.* TO `test`@`%`   |
+        | GRANT INSERT ON `mysql`.`user` TO `test`@`%`      |
+        | GRANT `readers`@`%` TO `test`@`%`                 |
+        +---------------------------------------------------+
+
+        Args:
+            grants (list): Grants of a user to parse.
+
+        Returns:
+            bool: True if the self.full_name has been found in grants,
+                otherwise returns False.
+        """
+        if not grants:
+            return False
+
+        for grant in grants:
+            if self.full_name in grant[0]:
+                return True
+
+        return False
 
 
 def main():
@@ -894,6 +950,7 @@ def main():
         admin=dict(type='str'),
         priv=dict(type='raw'),
         append_privs=dict(type='bool', default=False),
+        subtract_privs=dict(type='bool', default=False),
         members=dict(type='list', elements='str'),
         append_members=dict(type='bool', default=False),
         detach_members=dict(type='bool', default=False),
@@ -908,6 +965,7 @@ def main():
             ('admin', 'members'),
             ('admin', 'append_members'),
             ('admin', 'detach_members'),
+            ('append_privs', 'subtract_privs'),
         ),
     )
 
@@ -921,6 +979,7 @@ def main():
     connect_timeout = module.params['connect_timeout']
     config_file = module.params['config_file']
     append_privs = module.params['append_privs']
+    subtract_privs = module.boolean(module.params['subtract_privs'])
     members = module.params['members']
     append_members = module.params['append_members']
     detach_members = module.params['detach_members']
@@ -977,8 +1036,7 @@ def main():
             module.fail_json(msg=to_native(e))
 
         try:
-            valid_privs = get_valid_privs(cursor)
-            priv = privileges_unpack(priv, mode, valid_privs)
+            priv = privileges_unpack(priv, mode, ensure_usage=not subtract_privs)
         except Exception as e:
             module.fail_json(msg='Invalid privileges string: %s' % to_native(e))
 
@@ -1007,13 +1065,13 @@ def main():
     try:
         if state == 'present':
             if not role.exists:
-                if detach_members:
-                    members = None  # avoid adding unwanted members
+                if subtract_privs:
+                    priv = None  # avoid granting unwanted privileges
                 changed = role.add(members, priv, module.check_mode, admin,
                                    set_default_role_all)
 
             else:
-                changed = role.update(members, priv, module.check_mode, append_privs,
+                changed = role.update(members, priv, module.check_mode, append_privs, subtract_privs,
                                       append_members, detach_members, admin,
                                       set_default_role_all)
 
