@@ -194,7 +194,7 @@ class NetAppModule(object):
             return None, "Error: get_working_environment_details %s" % error
         return response, None
 
-    def get_aws_fsx_details(self, rest_api, header):
+    def get_aws_fsx_details(self, rest_api, header=None):
         '''
         Use working environment id and tenantID to get working environment details including:
         name: working environment name,
@@ -217,13 +217,61 @@ class NetAppModule(object):
         if count == 1:
             return fsx_details, None
         elif count > 1:
-            return response, "More than one AWS FSX found for %s, use working_environment_id for delete" \
+            return response, "More than one AWS FSx found for %s, use working_environment_id for delete" \
                              "or use different name for create" % self.parameters['name']
         return None, None
 
+    def get_aws_fsx_details_by_id(self, rest_api, header=None):
+        '''
+        Use working environment id and tenantID to get working environment details including:
+        publicID: working environment ID
+        '''
+        api = "/fsx-ontap/working-environments/%s" % self.parameters['tenant_id']
+        response, error, dummy = rest_api.get(api, None, header=header)
+        if error:
+            return response, "Error: get_aws_fsx_details %s" % error
+        for each in response:
+            if self.parameters.get('destination_working_environment_id') and each['id'] == self.parameters['destination_working_environment_id']:
+                return each, None
+        return None, None
+
+    def get_aws_fsx_details_by_name(self, rest_api, header=None):
+        '''
+        Use working environment name and tenantID to get working environment details including:
+        name: working environment name,
+        '''
+        api = "/fsx-ontap/working-environments/%s" % self.parameters['tenant_id']
+        count = 0
+        fsx_details = None
+        response, error, dummy = rest_api.get(api, None, header=header)
+        if error:
+            return response, "Error: get_aws_fsx_details_by_name %s" % error
+        for each in response:
+            if each['name'] == self.parameters['destination_working_environment_name']:
+                count += 1
+                fsx_details = each
+        if count == 1:
+            return fsx_details['id'], None
+        if count > 1:
+            return response, "More than one AWS FSx found for %s" % self.parameters['name']
+        return None, None
+
+    def get_aws_fsx_svm(self, rest_api, id, header=None):
+        '''
+        Use working environment id and tenantID to get FSx svm details including:
+        publicID: working environment ID
+        '''
+        api = "/occm/api/fsx/working-environments/%s/svms" % id
+        response, error, dummy = rest_api.get(api, None, header=header)
+        if error:
+            return response, "Error: get_aws_fsx_svm %s" % error
+        if len(response) == 0:
+            return None, "Error: no SVM found for %s" % id
+        return response[0]['name'], None
+
     def get_working_environment_detail_for_snapmirror(self, rest_api, headers):
 
-        source_working_env_detail, dest_working_env_detail = None, None
+        source_working_env_detail, dest_working_env_detail = {}, {}
         if self.parameters.get('source_working_environment_id'):
             api = '/occm/api/working-environments'
             working_env_details, error, dummy = rest_api.get(api, None, header=headers)
@@ -243,20 +291,43 @@ class NetAppModule(object):
             return None, None, "Cannot find working environment by source_working_environment_id or source_working_environment_name"
 
         if self.parameters.get('destination_working_environment_id'):
-            api = '/occm/api/working-environments'
-            working_env_details, error, dummy = rest_api.get(api, None, header=headers)
-            if error:
-                return None, None, "Error getting WE info: %s: %s" % (error, working_env_details)
-            for dummy, values in working_env_details.items():
-                for each in values:
-                    if each['publicId'] == self.parameters['destination_working_environment_id']:
-                        dest_working_env_detail = each
-                        break
+            if self.parameters['destination_working_environment_id'].startswith('fs-'):
+                if self.parameters.get('tenant_id'):
+                    working_env_details, error = self.get_aws_fsx_details_by_id(rest_api, header=headers)
+                    if error:
+                        return None, None, "Error getting WE info for FSx: %s: %s" % (error, working_env_details)
+                    dest_working_env_detail['publicId'] = self.parameters['destination_working_environment_id']
+                    svm_name, error = self.get_aws_fsx_svm(rest_api, self.parameters['destination_working_environment_id'], header=headers)
+                    if error:
+                        return None, None, "Error getting svm name for FSx: %s" % error
+                    dest_working_env_detail['svmName'] = svm_name
+                else:
+                    return None, None, "Cannot find FSx WE by destination WE %s, missing tenant_id" % self.parameters['destination_working_environment_id']
+            else:
+                api = '/occm/api/working-environments'
+                working_env_details, error, dummy = rest_api.get(api, None, header=headers)
+                if error:
+                    return None, None, "Error getting WE info: %s: %s" % (error, working_env_details)
+                for dummy, values in working_env_details.items():
+                    for each in values:
+                        if each['publicId'] == self.parameters['destination_working_environment_id']:
+                            dest_working_env_detail = each
+                            break
         elif self.parameters.get('destination_working_environment_name'):
-            dest_working_env_detail, error = self.get_working_environment_details_by_name(rest_api, headers,
-                                                                                          self.parameters['destination_working_environment_name'])
-            if error:
-                return None, None, error
+            if self.parameters.get('tenant_id'):
+                fsx_id, error = self.get_aws_fsx_details_by_name(rest_api, header=headers)
+                if error:
+                    return None, None, "Error getting WE info for FSx: %s" % error
+                dest_working_env_detail['publicId'] = fsx_id
+                svm_name, error = self.get_aws_fsx_svm(rest_api, fsx_id, header=headers)
+                if error:
+                    return None, None, "Error getting svm name for FSx: %s" % error
+                dest_working_env_detail['svmName'] = svm_name
+            else:
+                dest_working_env_detail, error = self.get_working_environment_details_by_name(rest_api, headers,
+                                                                                              self.parameters['destination_working_environment_name'])
+                if error:
+                    return None, None, error
         else:
             return None, None, "Cannot find working environment by destination_working_environment_id or destination_working_environment_name"
 
@@ -552,7 +623,7 @@ class NetAppModule(object):
         Fetch OCCM agent given its client id
         :return: agent details, error
         """
-        api = "/agents-mgmt/agent/" + rest_api.format_cliend_id(client_id)
+        api = "/agents-mgmt/agent/" + rest_api.format_client_id(client_id)
         headers = {
             "X-User-Token": rest_api.token_type + " " + rest_api.token,
         }
@@ -570,7 +641,7 @@ class NetAppModule(object):
         DEPRECATED - use get_occm_agent_by_id but the retrun value format is different!
         """
 
-        api = "/agents-mgmt/agent/" + rest_api.format_cliend_id(client_id)
+        api = "/agents-mgmt/agent/" + rest_api.format_client_id(client_id)
         headers = {
             "X-User-Token": rest_api.token_type + " " + rest_api.token,
         }
@@ -615,7 +686,7 @@ class NetAppModule(object):
         '''
         delete occm
         '''
-        api = '/agents-mgmt/agent/' + rest_api.format_cliend_id(client_id)
+        api = '/agents-mgmt/agent/' + rest_api.format_client_id(client_id)
         headers = {
             "X-User-Token": rest_api.token_type + " " + rest_api.token,
             "X-Tenancy-Account-Id": self.parameters['account_id'],
@@ -667,10 +738,13 @@ class NetAppModule(object):
                 "value": "string"
             },
             "customData": {
-            "value": "string"
+                "value": "string"
             },
             "environment": {
                 "value": "prod"
+            },
+            "storageAccount": {
+                "value": "string"
             }
         }
         """
@@ -708,18 +782,21 @@ class NetAppModule(object):
                 "type": "string"
             },
             "customData": {
-              "type": "string"
+                "type": "string"
             },
             "environment": {
-              "type": "string",
-              "defaultValue": "prod"
+                "type": "string",
+                "defaultValue": "prod"
+            },
+            "storageAccount": {
+                "type": "string"
             }
         },
         "variables": {
             "vnetId": "[parameters('virtualNetworkId')]",
             "subnetRef": "[parameters('subnetId')]",
             "networkInterfaceName": "[concat(parameters('virtualMachineName'),'-nic')]",
-            "diagnosticsStorageAccountName": "[concat(toLower(parameters('virtualMachineName')),'sa')]",
+            "diagnosticsStorageAccountName": "[parameters('storageAccount')]",
             "diagnosticsStorageAccountId": "[concat('Microsoft.Storage/storageAccounts/', variables('diagnosticsStorageAccountName'))]",
             "diagnosticsStorageAccountType": "Standard_LRS",
             "publicIpAddressName": "[concat(parameters('virtualMachineName'),'-ip')]",
@@ -954,7 +1031,7 @@ class NetAppModule(object):
             # no change
             return None, None
 
-    def compare_cvo_tags_labels(self, current_tags, user_tags, tag_name):
+    def compare_cvo_tags_labels(self, current_tags, user_tags):
         '''
         Compare exiting tags/labels and user input tags/labels to see if there is a change
         gcp_labels: label_key, label_value
@@ -1008,7 +1085,39 @@ class NetAppModule(object):
             return True, None
         else:
             # has tags in input parameters and existing CVO
-            return self.compare_cvo_tags_labels(current['userTags'], parameters[tag_name], tag_name)
+            return self.compare_cvo_tags_labels(current['userTags'], parameters[tag_name])
+
+    def get_license_type(self, rest_api, headers, provider, region, instance_type, ontap_version, license_name):
+        # Permutation query example:
+        # aws: /metadata/permutations?region=us-east-1&instance_type=m5.xlarge&version=ONTAP-9.10.1.T1
+        # azure: /metadata/permutations?region=westus&instance_type=Standard_E4s_v3&version=ONTAP-9.10.1.T1.azure
+        # gcp: /metadata/permutations?region=us-east1&instance_type=n2-standard-4&version=ONTAP-9.10.1.T1.gcp
+        # The examples of the ontapVersion in ontapClusterProperties response:
+        # AWS for both single and HA: 9.10.1RC1, 9.8
+        # AZURE single: 9.10.1RC1.T1.azure. For HA: 9.10.1RC1.T1.azureha
+        # GCP for both single and HA: 9.10.1RC1.T1, 9.8.T1
+        # To be used in permutation:
+        # AWS ontap_version format: ONTAP-x.x.x.T1 or ONTAP-x.x.x.T1.ha for Ha
+        # AZURE ontap_version format: ONTAP-x.x.x.T1.azure or ONTAP-x.x.x.T1.azureha for HA
+        # GCP ontap_version format: ONTAP-x.x.x.T1.gcp or ONTAP-x.x.x.T1.gcpha for HA
+        version = 'ONTAP-' + ontap_version
+        if provider == 'aws':
+            version += '.T1.ha' if self.parameters['is_ha'] else '.T1'
+        elif provider == 'gcp':
+            version += '.gcpha' if self.parameters['is_ha'] else '.gcp'
+        api = '%s/metadata/permutations' % rest_api.api_root_path
+        params = {'region': region,
+                  'version': version,
+                  'instance_type': instance_type
+                  }
+        response, error, dummy = rest_api.get(api, params=params, header=headers)
+        if error:
+            return None, "Error: get_license_type %s %s" % (response, error)
+        for item in response:
+            if item['license']['name'] == license_name:
+                return item['license']['type'], None
+
+        return None, "Error: get_license_type cannot get license type %s" % response
 
     def get_modify_cvo_params(self, rest_api, headers, desired, provider):
         modified = []
@@ -1016,13 +1125,11 @@ class NetAppModule(object):
             modified = ['svm_password']
         # Get current working environment property
         properties = ['ontapClusterProperties.fields(upgradeVersions)']
-        # instanceType in aws case is stored in clusterProperties
+        # instanceType in aws case is stored in awsProperties['instances'][0]['instanceType']
         if provider == 'aws':
-            properties.append('clusterProperties')
-            instance_type_container = 'clusterProperties'
+            properties.append('awsProperties')
         else:
             properties.append('providerProperties')
-            instance_type_container = 'providerProperties'
 
         we, err = self.get_working_environment_property(rest_api, headers, properties)
 
@@ -1035,9 +1142,25 @@ class NetAppModule(object):
         elif tier_level != desired['tier_level']:
             modified.append('tier_level')
 
-        if we[instance_type_container]['instanceType'] != desired['instance_type']:
+        if provider == 'aws':
+            current_instance_type = we['awsProperties']['instances'][0]['instanceType']
+            region = we['awsProperties']['regionName']
+        else:
+            current_instance_type = we['providerProperties']['instanceType']
+            region = we['providerProperties']['regionName']
+
+        if current_instance_type != desired['instance_type']:
             modified.append('instance_type')
 
+        # check if license type is changed
+        current_license_type, error = self.get_license_type(rest_api, headers, provider, region, current_instance_type,
+                                                            we['ontapClusterProperties']['ontapVersion'],
+                                                            we['ontapClusterProperties']['licenseType']['name'])
+        if err is not None:
+            return None, error
+        if current_license_type != desired['license_type']:
+            modified.append('license_type')
+
         if desired['upgrade_ontap_version'] is True:
             if desired['use_latest_version'] or desired['ontap_version'] == 'latest':
                 return None, "Error: To upgrade ONTAP image, the ontap_version must be a specific version"
@@ -1047,7 +1170,7 @@ class NetAppModule(object):
                     available_versions = []
                     for image_info in we['ontapClusterProperties']['upgradeVersions']:
                         available_versions.append(image_info['imageVersion'])
-                        # AWS ontap_version format: ONTAP-x.x.x.Tx pattern
+                        # AWS ontap_version format: ONTAP-x.x.x.Tx or ONTAP-x.x.x.Tx.ha for Ha
                         # AZURE ontap_version format: ONTAP-x.x.x.Tx.azure or .azureha for HA
                         # GCP ontap_version format: ONTAP-x.x.x.Tx.gcp or .gcpha for HA
                         # Tx is not relevant for ONTAP version. But it is needed for the CVO creation
@@ -1098,6 +1221,21 @@ class NetAppModule(object):
 
         return modify, None
 
+    def wait_cvo_update_complete(self, rest_api, headers):
+        retry_count = 65
+        if self.parameters['is_ha'] is True:
+            retry_count *= 2
+        for count in range(retry_count):
+            # get CVO status
+            we, err = self.get_working_environment_property(rest_api, headers, ['status'])
+            if err is not None:
+                return False, 'Error: get_working_environment_property failed: %s' % (str(err))
+            if we['status']['status'] != "UPDATING":
+                return True, None
+            time.sleep(60)
+
+        return False, 'Error: Taking too long for CVO to be active after update or not properly setup'
+
     def update_cvo_tags(self, api_root, rest_api, headers, tag_name, tag_list):
         body = {}
         tags = []
@@ -1138,7 +1276,10 @@ class NetAppModule(object):
         response, err, dummy = rest_api.put(api_root + "license-instance-type", body, header=headers)
         if err is not None:
             return False, 'Error: unexpected response on modify instance_type and instance_type: %s, %s' % (str(err), str(response))
-
+        # check upgrade status
+        dummy, err = self.wait_cvo_update_complete(rest_api, headers)
+        if err is not None:
+            return False, err
         return True, None
 
     def set_config_flag(self, rest_api, headers):
