@@ -10,7 +10,6 @@ na_cloudmanager_cvo_azure
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-
 DOCUMENTATION = '''
 
 module: na_cloudmanager_cvo_azure
@@ -47,9 +46,9 @@ options:
   instance_type:
     description:
     - The type of instance to use, which depends on the license type you chose.
-    - Explore ['Standard_DS3_v2']
-    - Standard ['Standard_DS4_v2, Standard_DS13_v2, Standard_L8s_v2']
-    - Premium ['Standard_DS5_v2', 'Standard_DS14_v2']
+    - Explore ['Standard_DS3_v2'].
+    - Standard ['Standard_DS4_v2, Standard_DS13_v2, Standard_L8s_v2'].
+    - Premium ['Standard_DS5_v2', 'Standard_DS14_v2'].
     - For more supported instance types, refer to Cloud Volumes ONTAP Release Notes.
     type: str
     default: Standard_DS4_v2
@@ -57,16 +56,16 @@ options:
   license_type:
     description:
     - The type of license to use.
-    - For single node ['azure-cot-explore-paygo', 'azure-cot-standard-paygo', 'azure-cot-premium-paygo', \
-     'azure-cot-premium-byol', 'capacity-paygo']
-    - For HA ['azure-ha-cot-standard-paygo', 'azure-ha-cot-premium-paygo', 'azure-ha-cot-premium-byol', \
-     'ha-capacity-paygo']
-    - Use capacity-paygo or ha-capacity-paygo for HA on selecting Bring Your Own License type Capacity-Based or Freemium.
-    - Use azure-cot-premium-boyl or azure-ha-cot-permium-boyl for HA on selecting Bring Your Own License type Node-Based.
+    - For single node by Capacity ['capacity-paygo'].
+    - For single node by Node paygo ['azure-cot-explore-paygo', 'azure-cot-standard-paygo', 'azure-cot-premium-paygo'].
+    - For single node by Node byol ['azure-cot-premium-byol'].
+    - For HA by Capacity ['ha-capacity-paygo'].
+    - For HA by Node paygo ['azure-ha-cot-standard-paygo', 'azure-ha-cot-premium-paygo'].
+    - For HA by Node byol ['azure-ha-cot-premium-byol'].
     choices: ['azure-cot-standard-paygo', 'azure-cot-premium-paygo', 'azure-cot-premium-byol', \
      'azure-cot-explore-paygo', 'azure-ha-cot-standard-paygo', 'azure-ha-cot-premium-paygo', \
-    'azure-ha-cot-premium-byol', 'capacity-paygo', 'ha-capacity-paygo']
-    default: 'azure-cot-standard-paygo'
+     'azure-ha-cot-premium-byol', 'capacity-paygo', 'ha-capacity-paygo']
+    default: 'capacity-paygo'
     type: str
 
   provided_license:
@@ -80,6 +79,7 @@ options:
     - Essential only available with Bring Your Own License Capacity-Based.
     - Professional available as an annual contract from a cloud provider or Bring Your Own License Capacity-Based.
     choices: ['Professional', 'Essential', 'Freemium']
+    default: 'Essential'
     type: str
     version_added: 21.12.0
 
@@ -116,14 +116,14 @@ options:
 
   allow_deploy_in_existing_rg:
     description:
-    - Indicates if to allow creation in existing resource group
+    - Indicates if to allow creation in existing resource group.
     type: bool
     default: false
 
   cidr:
     required: true
     description:
-    - The CIDR of the VNET.
+    - The CIDR of the VNET. If not provided, resource needs az login to authorize and fetch the cidr details from Azure.
     type: str
 
   location:
@@ -155,7 +155,7 @@ options:
   client_id:
     required: true
     description:
-    - The client ID of the Cloud Manager Connector.
+    - The connector ID of the Cloud Manager Connector.
     - You can find the ID from the Connector tab on [https://cloudmanager.netapp.com].
     type: str
 
@@ -188,7 +188,7 @@ options:
 
   ontap_version:
     description:
-    - The required ONTAP version. Ignored if 'use_latest_version' is set to true
+    - The required ONTAP version. Ignored if 'use_latest_version' is set to true.
     type: str
     default: 'latest'
 
@@ -200,8 +200,8 @@ options:
 
   serial_number:
     description:
-    - The serial number for the cluster
-    - Required when using one of these, 'azure-cot-premium-byol' or 'azure-ha-cot-premium-byol'
+    - The serial number for the cluster.
+    - Required when using one of these, 'azure-cot-premium-byol' or 'azure-ha-cot-premium-byol'.
     type: str
 
   tier_level:
@@ -225,7 +225,7 @@ options:
 
   capacity_tier:
     description:
-    - Whether to enable data tiering for the first data aggregate
+    - Whether to enable data tiering for the first data aggregate.
     choices: ['Blob', 'NONE']
     default: 'Blob'
     type: str
@@ -267,7 +267,6 @@ options:
       tag_value:
         description: The tag value.
         type: str
-
   is_ha:
     description:
     - Indicate whether the working environment is an HA pair or not.
@@ -380,9 +379,9 @@ class NetAppCloudManagerCVOAZURE:
             name=dict(required=True, type='str'),
             state=dict(required=False, choices=['present', 'absent'], default='present'),
             instance_type=dict(required=False, type='str', default='Standard_DS4_v2'),
-            license_type=dict(required=False, type='str', choices=AZURE_License_Types, default='azure-cot-standard-paygo'),
+            license_type=dict(required=False, type='str', choices=AZURE_License_Types, default='capacity-paygo'),
             workspace_id=dict(required=False, type='str'),
-            capacity_package_name=dict(required=False, type='str', choices=['Professional', 'Essential', 'Freemium']),
+            capacity_package_name=dict(required=False, type='str', choices=['Professional', 'Essential', 'Freemium'], default='Essential'),
             provided_license=dict(required=False, type='str'),
             subnet_id=dict(required=True, type='str'),
             vnet_id=dict(required=True, type='str'),
@@ -430,18 +429,20 @@ class NetAppCloudManagerCVOAZURE:
             required_if=[
                 ['license_type', 'capacity-paygo', ['capacity_package_name']],
                 ['license_type', 'ha-capacity-paygo', ['capacity_package_name']],
+                ['license_type', 'azure-cot-premium-byol', ['serial_number']],
+                ['license_type', 'azure-ha-cot-premium-byol', ['platform_serial_number_node1', 'platform_serial_number_node2']],
             ],
             supports_check_mode=True
         )
 
         self.na_helper = NetAppModule()
         self.parameters = self.na_helper.set_parameters(self.module.params)
-        self.changeable_params = ['svm_password', 'azure_tag', 'tier_level', 'ontap_version', 'instance_type']
+        self.changeable_params = ['svm_password', 'azure_tag', 'tier_level', 'ontap_version', 'instance_type', 'license_type']
         self.rest_api = CloudManagerRestAPI(self.module)
         self.rest_api.url += self.rest_api.environment_data['CLOUD_MANAGER_HOST']
         self.rest_api.api_root_path = '/occm/api/azure/%s' % ('ha' if self.parameters['is_ha'] else 'vsa')
         self.headers = {
-            'X-Agent-Id': self.rest_api.format_cliend_id(self.parameters['client_id'])
+            'X-Agent-Id': self.rest_api.format_client_id(self.parameters['client_id'])
         }
 
     def create_cvo_azure(self):
@@ -498,6 +499,10 @@ class NetAppCloudManagerCVOAZURE:
         if self.parameters.get('provided_license') is not None:
             json['vsaMetadata'].update({"providedLicense": self.parameters['provided_license']})
 
+        # clean default value if it is not by Capacity license
+        if not self.parameters['license_type'].endswith('capacity-paygo'):
+            json['vsaMetadata'].update({"capacityPackageName": ''})
+
         if self.parameters.get('capacity_package_name') is not None:
             json['vsaMetadata'].update({"capacityPackageName": self.parameters['capacity_package_name']})
 
@@ -646,12 +651,8 @@ class NetAppCloudManagerCVOAZURE:
             if self.parameters.get('platform_serial_number_node1') is None or self.parameters.get('platform_serial_number_node2') is None:
                 self.module.fail_json(msg="both platform_serial_number_node1 and platform_serial_number_node2 parameters are required"
                                           "when having ha type as true and license_type as azure-ha-cot-premium-byol")
-
-        if self.parameters.get('capacity_package_name') is not None:
-            if self.parameters['is_ha'] is True and self.parameters['license_type'] != 'ha-capacity-paygo':
-                self.module.fail_json(msg="license_type value must be ha-capacity-paygo")
-            if self.parameters['is_ha'] is False and self.parameters['license_type'] != 'capacity-paygo':
-                self.module.fail_json(msg="license_type value must be capacity-paygo")
+        if self.parameters['is_ha'] is True and self.parameters['license_type'] == 'capacity-paygo':
+            self.parameters['license_type'] == 'ha-capacity-paygo'
 
     def apply(self):
         """
