@@ -71,7 +71,6 @@ class TestMyModule(unittest.TestCase):
             'vpc_id': 'vpc-test',
             'subnet_id': 'subnet-test',
             'svm_password': 'password',
-            'license_type': 'cot-explore-paygo',
             'instance_type': 'm5.xlarge',
             'refresh_token': 'myrefresh_token',
             'is_ha': False
@@ -103,6 +102,21 @@ class TestMyModule(unittest.TestCase):
             'is_ha': False
         })
 
+    def set_args_create_bynode_cloudmanager_cvo_aws(self):
+        return dict({
+            'state': 'present',
+            'name': 'Dummyname',
+            'client_id': 'test',
+            'region': 'us-west-1',
+            'vpc_id': 'vpc-test',
+            'subnet_id': 'subnet-test',
+            'svm_password': 'password',
+            'refresh_token': 'myrefresh_token',
+            'license_type': 'cot-premium-byol',
+            'platform_serial_number': '12345678',
+            'is_ha': False
+        })
+
     def test_module_fail_when_required_args_missing(self):
         ''' required arguments are reported as errors '''
         with pytest.raises(AnsibleFailJson) as exc:
@@ -157,6 +171,8 @@ class TestMyModule(unittest.TestCase):
                                                  get_tenant, get_vpc, wait_on_completion, get_token):
         data = self.set_args_create_cloudmanager_cvo_aws()
         data['is_ha'] = True
+        data['license_type'] = 'ha-capacity-paygo'
+        data['capacity_package_name'] = 'Essential'
         data.pop('subnet_id')
         set_module_args(data)
         get_token.return_value = 'test', 'test'
@@ -247,9 +263,7 @@ class TestMyModule(unittest.TestCase):
     def test_create_cloudmanager_cvo_aws_nodebase_license_pass(self, get_post_api,
                                                                get_working_environment_details_by_name, get_nss,
                                                                get_tenant, get_vpc, wait_on_completion, get_token):
-        data = self.set_args_create_cloudmanager_cvo_aws()
-        data['license_type'] = 'cot-premium-byol'
-        data['platform_serial_number'] = '12345678'
+        data = self.set_args_create_bynode_cloudmanager_cvo_aws()
         set_module_args(data)
         get_token.return_value = 'test', 'test'
         my_obj = my_module()
@@ -277,7 +291,7 @@ class TestMyModule(unittest.TestCase):
     def test_create_cloudmanager_cvo_aws_ha_nodebase_license_pass(self, get_post_api,
                                                                   get_working_environment_details_by_name, get_nss,
                                                                   get_tenant, get_vpc, wait_on_completion, get_token):
-        data = self.set_args_create_cloudmanager_cvo_aws()
+        data = self.set_args_create_bynode_cloudmanager_cvo_aws()
         data['license_type'] = 'ha-cot-premium-byol'
         data['platform_serial_number_node1'] = '12345678'
         data['platform_serial_number_node2'] = '23456789'
@@ -334,11 +348,11 @@ class TestMyModule(unittest.TestCase):
         data = self.set_default_args_pass_check()
         data['svm_password'] = 'newpassword'
         data['update_svm_password'] = True
-        data['ontap_version'] = 'ONTAP-9.10.1P3.T1.azure'
+        data['ontap_version'] = 'ONTAP-9.10.1P3.T1'
         data['upgrade_ontap_version'] = True
         set_module_args(data)
 
-        modify = ['svm_password', 'aws_tag', 'tier_level', 'ontap_version', 'instance_type']
+        modify = ['svm_password', 'aws_tag', 'tier_level', 'ontap_version', 'instance_type', 'license_type']
 
         my_cvo = {
             'name': 'TestA',
@@ -356,17 +370,27 @@ class TestMyModule(unittest.TestCase):
                         'ontapClusterProperties': {
                             'capacityTierInfo': {'tierLevel': 'normal'},
                             'licenseType': {'capacityLimit': {'size': 2.0, 'unit': 'TB'},
-                                            'name': 'Cloud Volumes ONTAP Explore'},
+                                            'name': 'Cloud Volumes ONTAP Capacity Based Charging'},
                             'ontapVersion': '9.10.0',
                             'upgradeVersions': [{'autoUpdateAllowed': False,
                                                  'imageVersion': 'ONTAP-9.10.1P3',
                                                  'lastModified': 1634467078000}],
                             'writingSpeedState': 'NORMAL'},
-                        'clusterProperties': {
-                            'instanceType': 'm5.xlarge',
-                            'licenseExpiryDate': 0,
-                            'licenseType': {'capacityLimit': {'size': 2.0, 'unit': 'TB'},
-                                            'name': 'Cloud Volumes ONTAP Explore'}, }
+                        'awsProperties': {'accountId': u'123456789011',
+                                          'availabilityZones': [u'us-east-1b'],
+                                          'bootDiskSize': None,
+                                          'cloudProviderAccountId': None,
+                                          'coreDiskExists': True,
+                                          'instances': [{'availabilityZone': 'us-east-1b',
+                                                         'id': 'i-31',
+                                                         'imageId': 'ami-01a6f1234cb1ec375',
+                                                         'instanceProfileId': 'SimFabricPoolInstanceProfileId',
+                                                         'instanceType': 'm5.2xlarge',
+                                                         'isOCCMInstance': False,
+                                                         'isVsaInstance': True,
+                                                         }],
+                                          'regionName': 'us-west-1',
+                                          }
                         }
         get_property.return_value = cvo_property, None
         cvo_details = {'cloudProviderName': 'Amazon',
@@ -390,7 +414,7 @@ class TestMyModule(unittest.TestCase):
                 update_tier_level.return_value = True, None
             elif item == 'ontap_version':
                 upgrade_ontap_image.return_value = True, None
-            elif item == 'instance_type':
+            elif item == 'instance_type' or item == 'license_type':
                 update_instance_license_type.return_value = True, None
 
         with pytest.raises(AnsibleExitJson) as exc:
