@@ -45,7 +45,7 @@ extends_documentation_fragment:
 
 EXAMPLES = r"""
 - name: collect default set of information
-  purefa_info:
+  purestorage.flasharray.purefa_info:
     fa_url: 10.10.10.2
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
   register: array_info
@@ -54,7 +54,7 @@ EXAMPLES = r"""
     msg: "{{ array_info['purefa_info']['default'] }}"
 
 - name: collect configuration and capacity information
-  purefa_info:
+  purestorage.flasharray.purefa_info:
     gather_subset:
       - config
     fa_url: 10.10.10.2
@@ -65,7 +65,7 @@ EXAMPLES = r"""
     msg: "{{ array_info['purefa_info']['config'] }}"
 
 - name: collect all information
-  purefa_info:
+  purestorage.flasharray.purefa_info:
     gather_subset:
       - all
     fa_url: 10.10.10.2
@@ -462,6 +462,7 @@ DIR_QUOTA_API_VERSION = "2.7"
 SHARED_CAP_API_VERSION = "2.9"
 PURE_OUI = "naa.624a9370"
 SAFE_MODE_VERSION = "2.10"
+PER_PG_VERSION = "2.13"
 SAML2_VERSION = "2.11"
 
 
@@ -469,6 +470,7 @@ def generate_default_dict(module, array):
     default_info = {}
     defaults = array.get()
     api_version = array._list_available_rest_versions()
+    default_info["api_versions"] = api_version
     if FILES_API_VERSION in api_version:
         arrayv6 = get_array(module)
         default_info["snapshot_policies"] = len(arrayv6.get_policies_snapshot().items)
@@ -711,6 +713,28 @@ def generate_filesystems_dict(array):
     return files_info
 
 
+def generate_pgsnaps_dict(array):
+    pgsnaps_info = {}
+    snapshots = list(array.get_protection_group_snapshots().items)
+    for snapshot in range(0, len(snapshots)):
+        s_name = snapshots[snapshot].name
+        pgsnaps_info[s_name] = {
+            "destroyed": snapshots[snapshot].destroyed,
+            "source": snapshots[snapshot].source.name,
+            "suffix": snapshots[snapshot].suffix,
+            "snapshot_space": snapshots[snapshot].space.snapshots,
+        }
+        if pgsnaps_info[s_name]["destroyed"]:
+            pgsnaps_info[s_name]["time_remaining"] = snapshots[snapshot].time_remaining
+        try:
+            pgsnaps_info[s_name]["manual_eradication"] = snapshots[
+                snapshot
+            ].eradication_config.manual_eradication
+        except AttributeError:
+            pass
+    return pgsnaps_info
+
+
 def generate_dir_snaps_dict(array):
     dir_snaps_info = {}
     snapshots = list(array.get_directory_snapshots().items)
@@ -895,22 +919,36 @@ def generate_capacity_dict(module, array):
         arrayv6 = get_array(module)
         total_capacity = list(arrayv6.get_arrays().items)[0].capacity
         capacity = list(arrayv6.get_arrays_space().items)[0]
-        capacity_info["provisioned_space"] = capacity.space["total_provisioned"]
-        capacity_info["free_space"] = total_capacity - capacity.space["total_physical"]
+        capacity_info["provisioned_space"] = getattr(
+            capacity.space, "total_provisioned", 0
+        )
+        capacity_info["free_space"] = total_capacity - getattr(
+            capacity.space, "total_physical", 0
+        )
         capacity_info["total_capacity"] = total_capacity
-        capacity_info["data_reduction"] = capacity.space["data_reduction"]
-        capacity_info["system_space"] = capacity.space["system"]
-        capacity_info["volume_space"] = capacity.space["unique"]
-        capacity_info["shared_space"] = capacity.space["shared"]
-        capacity_info["snapshot_space"] = capacity.space["snapshots"]
-        capacity_info["thin_provisioning"] = capacity.space["thin_provisioning"]
-        capacity_info["total_reduction"] = capacity.space["total_reduction"]
-        capacity_info["replication"] = capacity.space["replication"]
+        capacity_info["data_reduction"] = getattr(capacity.space, "data_reduction", 0)
+        capacity_info["system_space"] = getattr(capacity.space, "system", 0)
+        capacity_info["volume_space"] = getattr(capacity.space, "unique", 0)
+        capacity_info["shared_space"] = getattr(capacity.space, "shared", 0)
+        capacity_info["snapshot_space"] = getattr(capacity.space, "snapshots", 0)
+        capacity_info["thin_provisioning"] = getattr(
+            capacity.space, "thin_provisioning", 0
+        )
+        capacity_info["total_reduction"] = getattr(capacity.space, "total_reduction", 0)
+        capacity_info["replication"] = getattr(capacity.space, "replication", 0)
         if SHARED_CAP_API_VERSION in api_version:
-            capacity_info["shared_effective"] = capacity.space["shared_effective"]
-            capacity_info["snapshots_effective"] = capacity.space["snapshots_effective"]
-            capacity_info["unique_effective"] = capacity.space["total_effective"]
-            capacity_info["total_effective"] = capacity.space["total_effective"]
+            capacity_info["shared_effective"] = getattr(
+                capacity.space, "shared_effective", 0
+            )
+            capacity_info["snapshots_effective"] = getattr(
+                capacity.space, "snapshots_effective", 0
+            )
+            capacity_info["unique_effective"] = getattr(
+                capacity.space, "total_effective", 0
+            )
+            capacity_info["total_effective"] = getattr(
+                capacity.space, "total_effective", 0
+            )
     elif CAP_REQUIRED_API_VERSION in api_version:
         volumes = array.list_volumes(pending=True)
         capacity_info["provisioned_space"] = sum(item["size"] for item in volumes)
@@ -1153,6 +1191,16 @@ def generate_del_vol_dict(module, array):
                     "namespace": voltags[voltag]["namespace"],
                 }
                 volume_info[volume]["tags"].append(tagdict)
+    if SAFE_MODE_VERSION in api_version:
+        volumes = list(arrayv6.get_volumes(destroyed=True).items)
+        for vol in range(0, len(volumes)):
+            name = volumes[vol].name
+            volume_info[name]["priority"] = volumes[vol].priority
+            volume_info[name]["priority_adjustment"] = volumes[
+                vol
+            ].priority_adjustment.priority_adjustment_operator + str(
+                volumes[vol].priority_adjustment.priority_adjustment_value
+            )
     return volume_info
 
 
@@ -1244,6 +1292,16 @@ def generate_vol_dict(module, array):
                 volume_info[volume]["host_encryption_key_status"] = e2ees[e2ee][
                     "host_encryption_key_status"
                 ]
+    if SAFE_MODE_VERSION in api_version:
+        volumes = list(arrayv6.get_volumes(destroyed=False).items)
+        for vol in range(0, len(volumes)):
+            name = volumes[vol].name
+            volume_info[name]["priority"] = volumes[vol].priority
+            volume_info[name]["priority_adjustment"] = volumes[
+                vol
+            ].priority_adjustment.priority_adjustment_operator + str(
+                volumes[vol].priority_adjustment.priority_adjustment_value
+            )
     cvols = array.list_volumes(connect=True)
     for cvol in range(0, len(cvols)):
         volume = cvols[cvol]["name"]
@@ -1374,6 +1432,16 @@ def generate_pgroups_dict(module, array):
                         )
             else:
                 pgroups_info[protgroup]["deleted_volumes"] = None
+        if PER_PG_VERSION in api_version:
+            try:
+                pgroups_info[protgroup]["retention_lock"] = list(
+                    array_v6.get_protection_groups(names=[protgroup]).items
+                )[0].retention_lock
+                pgroups_info[protgroup]["manual_eradication"] = list(
+                    array_v6.get_protection_groups(names=[protgroup]).items
+                )[0].eradication_config.manual_eradication
+            except Exception:
+                pass
     return pgroups_info
 
 
@@ -1510,10 +1578,11 @@ def generate_conn_array_dict(module, array):
             arrayname = carrays[carray].name
             conn_array_info[arrayname] = {
                 "array_id": carrays[carray].id,
-                "version": carrays[carray].version,
+                "version": getattr(carrays[carray], "version", None),
+                "status": carrays[carray].status,
                 "type": carrays[carray].type,
-                "mgmt_ip": carrays[carray].management_address,
-                "repl_ip": carrays[carray].replication_addresses,
+                "mgmt_ip": getattr(carrays[carray], "management_address", "-"),
+                "repl_ip": getattr(carrays[carray], "replication_addresses", "-"),
                 "transport": carrays[carray].replication_transport,
             }
 
@@ -1567,16 +1636,98 @@ def generate_apps_dict(array):
     return apps_info
 
 
-def generate_vgroups_dict(array):
+def generate_vgroups_dict(module, array):
     vgroups_info = {}
     api_version = array._list_available_rest_versions()
     if AC_REQUIRED_API_VERSION in api_version:
-        vgroups = array.list_vgroups()
+        vgroups = array.list_vgroups(pending=False)
         for vgroup in range(0, len(vgroups)):
             virtgroup = vgroups[vgroup]["name"]
             vgroups_info[virtgroup] = {
                 "volumes": vgroups[vgroup]["volumes"],
             }
+    if V6_MINIMUM_API_VERSION in api_version:
+        arrayv6 = get_array(module)
+        vgroups = list(arrayv6.get_volume_groups(destroyed=False).items)
+        for vgroup in range(0, len(vgroups)):
+            name = vgroups[vgroup].name
+            vgroups_info[name]["snapshots_space"] = vgroups[vgroup].space.snapshots
+            # Provide system as this matches the old naming convention
+            vgroups_info[name]["system"] = vgroups[vgroup].space.unique
+            vgroups_info[name]["unique_space"] = vgroups[vgroup].space.unique
+            vgroups_info[name]["virtual_space"] = vgroups[vgroup].space.virtual
+            vgroups_info[name]["data_reduction"] = vgroups[vgroup].space.data_reduction
+            vgroups_info[name]["total_reduction"] = vgroups[
+                vgroup
+            ].space.total_reduction
+            vgroups_info[name]["total_provisioned"] = vgroups[
+                vgroup
+            ].space.total_provisioned
+            vgroups_info[name]["thin_provisioning"] = vgroups[
+                vgroup
+            ].space.thin_provisioning
+            vgroups_info[name]["bandwidth_limit"] = getattr(
+                vgroups[vgroup].qos, "bandwidth_limit", ""
+            )
+            vgroups_info[name]["iops_limit"] = getattr(
+                vgroups[vgroup].qos, "iops_limit", ""
+            )
+        if SAFE_MODE_VERSION in api_version:
+            for vgroup in range(0, len(vgroups)):
+                name = vgroups[vgroup].name
+                vgroups_info[name]["priority_adjustment"] = vgroups[
+                    vgroup
+                ].priority_adjustment.priority_adjustment_operator + str(
+                    vgroups[vgroup].priority_adjustment.priority_adjustment_value
+                )
+    return vgroups_info
+
+
+def generate_del_vgroups_dict(module, array):
+    vgroups_info = {}
+    api_version = array._list_available_rest_versions()
+    if AC_REQUIRED_API_VERSION in api_version:
+        vgroups = array.list_vgroups(pending_only=True)
+        for vgroup in range(0, len(vgroups)):
+            virtgroup = vgroups[vgroup]["name"]
+            vgroups_info[virtgroup] = {
+                "volumes": vgroups[vgroup]["volumes"],
+            }
+    if V6_MINIMUM_API_VERSION in api_version:
+        arrayv6 = get_array(module)
+        vgroups = list(arrayv6.get_volume_groups(destroyed=True).items)
+        for vgroup in range(0, len(vgroups)):
+            name = vgroups[vgroup].name
+            vgroups_info[name]["snapshots_space"] = vgroups[vgroup].space.snapshots
+            # Provide system as this matches the old naming convention
+            vgroups_info[name]["system"] = vgroups[vgroup].space.unique
+            vgroups_info[name]["unique_space"] = vgroups[vgroup].space.unique
+            vgroups_info[name]["virtual_space"] = vgroups[vgroup].space.virtual
+            vgroups_info[name]["data_reduction"] = vgroups[vgroup].space.data_reduction
+            vgroups_info[name]["total_reduction"] = vgroups[
+                vgroup
+            ].space.total_reduction
+            vgroups_info[name]["total_provisioned"] = vgroups[
+                vgroup
+            ].space.total_provisioned
+            vgroups_info[name]["thin_provisioning"] = vgroups[
+                vgroup
+            ].space.thin_provisioning
+            vgroups_info[name]["time_remaining"] = (vgroups[vgroup].time_remaining,)
+            vgroups_info[name]["bandwidth_limit"] = getattr(
+                vgroups[vgroup].qos, "bandwidth_limit", ""
+            )
+            vgroups_info[name]["iops_limit"] = getattr(
+                vgroups[vgroup].qos, "iops_limit", ""
+            )
+        if SAFE_MODE_VERSION in api_version:
+            for vgroup in range(0, len(vgroups)):
+                name = vgroups[vgroup].name
+                vgroups_info[name]["priority_adjustment"] = vgroups[
+                    vgroup
+                ].priority_adjustment.priority_adjustment_operator + str(
+                    vgroups[vgroup].priority_adjustment.priority_adjustment_value
+                )
     return vgroups_info
 
 
@@ -1801,7 +1952,8 @@ def main():
     if "admins" in subset or "all" in subset:
         info["admins"] = generate_admin_dict(array)
     if "vgroups" in subset or "all" in subset:
-        info["vgroups"] = generate_vgroups_dict(array)
+        info["vgroups"] = generate_vgroups_dict(module, array)
+        info["deleted_vgroups"] = generate_del_vgroups_dict(module, array)
     if "offload" in subset or "all" in subset:
         info["azure_offload"] = generate_azure_offload_dict(array)
         info["nfs_offload"] = generate_nfs_offload_dict(array)
@@ -1831,6 +1983,8 @@ def main():
             info["clients"] = generate_clients_dict(array_v6)
         if "dir_snaps" in subset or "all" in subset:
             info["dir_snaps"] = generate_dir_snaps_dict(array_v6)
+        if "snapshots" in subset or "all" in subset:
+            info["pg_snapshots"] = generate_pgsnaps_dict(array_v6)
 
     module.exit_json(changed=False, purefa_info=info)
 
