@@ -25,7 +25,10 @@ from ansible.module_utils.basic import AnsibleModule, missing_required_lib, env_
 from ansible.module_utils._text import to_bytes, to_native
 from ansible.module_utils import six
 
-from distutils.version import LooseVersion
+try:
+    from ansible_collections.theforeman.foreman.plugins.module_utils._version import LooseVersion
+except ImportError:
+    from plugins.module_utils._version import LooseVersion
 
 try:
     try:
@@ -325,9 +328,10 @@ class HostMixin(ParametersMixin):
                 ak_param = {'name': 'kt_activation_keys', 'parameter_type': 'string', 'value': self.foreman_params.pop('activation_keys')}
                 self.foreman_params['parameters'] = parameters + [ak_param]
             elif 'parameters' in self.foreman_params and entity is not None:
-                ak_param = next((param for param in entity.get('parameters') if param['name'] == 'kt_activation_keys'), None)
-                if ak_param:
-                    self.foreman_params['parameters'].append(ak_param)
+                current_ak_param = next((param for param in entity.get('parameters') if param['name'] == 'kt_activation_keys'), None)
+                desired_ak_param = next((param for param in self.foreman_params['parameters'] if param['name'] == 'kt_activation_keys'), None)
+                if current_ak_param and desired_ak_param is None:
+                    self.foreman_params['parameters'].append(current_ak_param)
 
         self.validate_parameters()
 
@@ -380,6 +384,11 @@ class ForemanAnsibleModule(AnsibleModule):
         self._foremanapi_password = self.foreman_params.pop('password')
         self._foremanapi_validate_certs = self.foreman_params.pop('validate_certs')
 
+        if self._foremanapi_server_url.lower().startswith('http://'):
+            self.warn("You have configured a plain HTTP server URL. All communication will happen unencrypted.")
+        elif not self._foremanapi_server_url.lower().startswith('https://'):
+            self.fail_json(msg="The server URL needs to be either HTTPS or HTTP!")
+
         self.task_timeout = 60
         self.task_poll = 4
 
@@ -930,17 +939,25 @@ class ForemanAnsibleModule(AnsibleModule):
     def auto_lookup_nested_entities(self):
         for key, entity_spec in self.foreman_spec.items():
             if entity_spec.get('type') in {'nested_list'}:
-                for nested_key, nested_spec in self.foreman_spec[key]['foreman_spec'].items():
+                for nested_key, nested_spec in entity_spec['foreman_spec'].items():
                     for item in self.foreman_params.get(key, []):
                         if (nested_key in item and nested_spec.get('resolve', True)
                                 and not _is_resolved(nested_spec, item[nested_key])):
                             item[nested_key] = self._lookup_entity(item[nested_key], nested_spec)
 
     def record_before(self, resource, entity):
-        self._before[resource].append(entity)
+        if isinstance(entity, dict):
+            to_record = _recursive_dict_without_none(entity)
+        else:
+            to_record = entity
+        self._before[resource].append(to_record)
 
     def record_after(self, resource, entity):
-        self._after[resource].append(entity)
+        if isinstance(entity, dict):
+            to_record = _recursive_dict_without_none(entity)
+        else:
+            to_record = entity
+        self._after[resource].append(to_record)
 
     def record_after_full(self, resource, entity):
         self._after_full[resource].append(entity)
@@ -1073,11 +1090,11 @@ class ForemanAnsibleModule(AnsibleModule):
         """
         payload = {}
         desired_entity = _flatten_entity(desired_entity, foreman_spec)
-        current_entity = _flatten_entity(current_entity, foreman_spec)
+        current_flat_entity = _flatten_entity(current_entity, foreman_spec)
         for key, value in desired_entity.items():
             foreman_type = foreman_spec[key].get('type', 'str')
             new_value = value
-            old_value = current_entity.get(key)
+            old_value = current_flat_entity.get(key)
             # String comparison needs extra care in face of unicode
             if foreman_type == 'str':
                 old_value = to_native(old_value)
@@ -1095,14 +1112,14 @@ class ForemanAnsibleModule(AnsibleModule):
             if new_value != old_value:
                 payload[key] = value
         if self._validate_supported_payload(resource, 'update', payload):
-            payload['id'] = current_entity['id']
+            payload['id'] = current_flat_entity['id']
             if not self.check_mode:
                 if params:
                     payload.update(params)
                 return self.resource_action(resource, 'update', payload)
             else:
                 # In check_mode we emulate the server updating the entity
-                fake_entity = current_entity.copy()
+                fake_entity = current_flat_entity.copy()
                 fake_entity.update(payload)
                 self.set_changed()
                 return fake_entity
@@ -1314,6 +1331,8 @@ class ForemanStatelessEntityAnsibleModule(ForemanAnsibleModule):
         if 'parent' in self.foreman_spec and self.foreman_spec['parent'].get('type') == 'entity':
             if 'resouce_type' not in self.foreman_spec['parent']:
                 self.foreman_spec['parent']['resource_type'] = self.foreman_spec['entity']['resource_type']
+            if 'failsafe' not in self.foreman_spec['parent']:
+                self.foreman_spec['parent']['failsafe'] = True
             current, parent = split_fqn(self.foreman_params[self.entity_key])
             if isinstance(self.foreman_params.get('parent'), six.string_types):
                 if parent:
@@ -1423,10 +1442,14 @@ class ForemanEntityAnsibleModule(ForemanStatelessEntityAnsibleModule):
     def run(self, **kwargs):
         """ lookup entities, ensure entity, remove sensitive data, manage parameters.
         """
+        parent_name = self.foreman_params.get('parent')
         if ('parent' in self.foreman_spec and self.foreman_spec['parent'].get('type') == 'entity'
-                and self.desired_absent and 'parent' in self.foreman_params and self.lookup_entity('parent') is None):
-            # Parent does not exist so just exit here
-            return None
+                and 'parent' in self.foreman_params and self.lookup_entity('parent') is None):
+            if self.desired_absent:
+                # Parent does not exist so just exit here
+                return None
+            else:
+                self.fail_json(msg="Couldn't find parent '{0}' for '{1}'.".format(parent_name, self.foreman_params['name']))
         if not self.desired_absent:
             self.auto_lookup_entities()
         entity = self.lookup_entity('entity')
@@ -1778,20 +1801,30 @@ def build_fqn(name, parent=None):
 
 # Helper for puppetclasses
 def ensure_puppetclasses(module, entity_type, entity, expected_puppetclasses=None):
-    puppetclasses_resource = '{0}_classes'.format(entity_type)
-    if expected_puppetclasses:
+    if expected_puppetclasses is not None:
+        puppetclasses_resource = '{0}_classes'.format(entity_type)
         expected_puppetclasses = module.find_puppetclasses(expected_puppetclasses, environment=entity['environment_id'], thin=True)
-    current_puppetclasses = entity.pop('puppetclass_ids', [])
-    if expected_puppetclasses:
+        current_puppetclasses = entity.get('puppetclasses', [])
+        current_puppetclass_ids = [pc['id'] for pc in current_puppetclasses]
+        previous_puppetclass_ids = current_puppetclass_ids[:]
         for puppetclass in expected_puppetclasses:
-            if puppetclass['id'] in current_puppetclasses:
-                current_puppetclasses.remove(puppetclass['id'])
+            if puppetclass['id'] in current_puppetclass_ids:
+                # Nothing to do, prevent removal
+                previous_puppetclass_ids.remove(puppetclass['id'])
             else:
                 payload = {'{0}_id'.format(entity_type): entity['id'], 'puppetclass_id': puppetclass['id']}
                 module.ensure_entity(puppetclasses_resource, {}, None, params=payload, state='present', foreman_spec={})
-        if len(current_puppetclasses) > 0:
-            for leftover_puppetclass in current_puppetclasses:
-                module.ensure_entity(puppetclasses_resource, {}, {'id': leftover_puppetclass}, {'hostgroup_id': entity['id']}, state='absent', foreman_spec={})
+                # Add to entity for reporting
+                current_puppetclass_ids.append(puppetclass['id'])
+
+        for leftover_puppetclass in previous_puppetclass_ids:
+            payload = {'{0}_id'.format(entity_type): entity['id']}
+            module.ensure_entity(
+                puppetclasses_resource, {}, {'id': leftover_puppetclass},
+                params=payload, state='absent', foreman_spec={},
+            )
+            current_puppetclass_ids.remove(leftover_puppetclass)
+        entity['puppetclass_ids'] = current_puppetclass_ids
 
 
 # Helper constants
@@ -1816,12 +1849,12 @@ TEMPLATE_KIND_LIST = [
     'Bootdisk',
     'cloud-init',
     'finish',
+    'host_init_config',
     'iPXE',
     'job_template',
     'kexec',
     'POAP',
     'provision',
-    'ptable',
     'PXEGrub',
     'PXEGrub2',
     'PXELinux',
